@@ -4,7 +4,7 @@ from office365.runtime.odata.odata_request import ODataRequest
 from office365.runtime.odata.v4_json_format import V4JsonFormat
 from office365.runtime.resource_path import ResourcePath
 from office365.runtime.http.http_method import HttpMethod
-from office365.directory.user import User
+from office365.graph.directory.user import User
 
 
 class OutlookClient(ClientRuntimeContext):
@@ -19,8 +19,8 @@ class OutlookClient(ClientRuntimeContext):
     def get_pending_request(self):
         return self._pendingRequest
 
-    @staticmethod
-    def _build_specific_query(request, query):
+    def _build_specific_query(self, request):
+        query = self.get_pending_request().current_query
         if isinstance(query, UpdateEntityQuery):
             request.method = HttpMethod.Patch
         elif isinstance(query, DeleteEntityQuery):
