@@ -1,10 +1,18 @@
+from office365.runtime.client_value_object import ClientValueObject
 from office365.runtime.odata.odata_query_options import QueryOptions
 
 
 class ClientObject(object):
-    """Base client object"""
 
     def __init__(self, context, resource_path=None, properties=None, parent_collection=None):
+        """
+        Base client object
+
+        :type parent_collection: office365.runtime.client_object_collection.ClientObjectCollection or None
+        :type properties: dict or None
+        :type resource_path: office365.runtime.resource_path.ResourcePath or None
+        :type context: office365.runtime.client_runtime_context.ClientRuntimeContext
+        """
         self._properties = {}
         self._changes = []
         self._entity_type_name = None
@@ -18,17 +26,16 @@ class ClientObject(object):
 
     def is_property_available(self, name):
         """Returns a Boolean value that indicates whether the specified property has been retrieved or set."""
-        if name in self.properties and not (isinstance(self.properties[name], dict)
-                                            and '__deferred' in self.properties[name]):
+        if name in self.properties:
             return True
         return False
 
     def expand(self, names):
-        self.queryOptions.expand = names
+        self.query_options.expand = names
         return self
 
     def select(self, names):
-        self.queryOptions.select = names
+        self.query_options.select = names
         return self
 
     def remove_from_parent_collection(self):
@@ -40,36 +47,50 @@ class ClientObject(object):
         """Set resource property value"""
         if persist_changes:
             self._changes.append(name)
+
         safe_name = name[0].lower() + name[1:]
         if hasattr(self, safe_name):
-            child_prop = getattr(self, safe_name)
-            if isinstance(child_prop, ClientObject):  # is navigation property?
-                pass
-                # child_prop.map_json(value)
-        self._properties[name] = value
-
-    def map_json(self, json):
-        [self.set_property(k, v, False) for k, v in json.items() if k != '__metadata']
+            prop_type = getattr(self, safe_name)
+            if isinstance(prop_type, ClientObject) or isinstance(prop_type, ClientValueObject):
+                [prop_type.set_property(k, v, persist_changes) for k, v in value.items()]
+                self._properties[name] = prop_type
+            else:
+                self._properties[name] = value
+        else:
+            self._properties[name] = value
 
     def to_json(self):
         return dict((k, v) for k, v in self.properties.items() if k in self._changes)
 
+    def ensure_property(self, name, action):
+        """
+        Ensures property is loaded
+
+        :type action: any
+        :type name: str
+        """
+        if not self.is_property_available(name):
+            self.context.load(self, [name])
+            self.context.afterExecuteOnce += action
+        else:
+            action(self)
+
     @property
-    def entityTypeName(self):
+    def entity_type_name(self):
         if self._entity_type_name is None:
             self._entity_type_name = "SP." + type(self).__name__
         return self._entity_type_name
 
-    @entityTypeName.setter
-    def entityTypeName(self, value):
+    @entity_type_name.setter
+    def entity_type_name(self, value):
         self._entity_type_name = value
 
     @property
-    def resourceUrl(self):
+    def resource_url(self):
         """Generate resource Url"""
-        if self.resourcePath:
-            url = self.context.serviceRootUrl + self.resourcePath.to_url()
-            if not self.queryOptions.is_empty:
+        if self.resource_path:
+            url = self.context.service_root_url + self.resource_path.to_url()
+            if not self.query_options.is_empty:
                 url = url + "?" + self._query_options.to_url()
             return url
         return None
@@ -79,17 +100,13 @@ class ClientObject(object):
         return self._context
 
     @property
-    def resourcePath(self):
+    def resource_path(self):
         return self._resource_path
 
     @property
-    def queryOptions(self):
+    def query_options(self):
         return self._query_options
 
-    @property
-    def typeName(self):
-        return self.__module__ + "." + self.__class__.__name__
-
     @property
     def properties(self):
         return self._properties
