@@ -4,11 +4,10 @@ from pydoc import locate
 class ODataModel(object):
     """OData model"""
     _types = {}
-    _namespaces = ['directory', 'onedrive', 'outlookservices']
+    _namespaces = ['directory', 'onedrive', 'outlookservices', 'teams']
 
     def resolve_type(self, schema):
         type_alias = schema['name']
-
         types = [locate("office365.{0}.{1}".format(ns, type_alias)) for ns in self._namespaces]
         found_modules = [t for t in types if t is not None]
         if any(found_modules):
