@@ -3,10 +3,19 @@ class ResourcePath(object):
     """OData resource path"""
 
     def __init__(self, segment, parent=None):
+        """
+
+        :type parent: ResourcePath
+        :type segment: str
+        """
         self._segment = segment
         self._parent = parent
 
     def to_url(self):
+        """
+        Builds url
+        :rtype: str
+        """
         delimiter = '/'
         current = self
         segments = []
