@@ -1,24 +1,42 @@
+from functools import partial
 from office365.runtime.client_object import ClientObject
-from office365.runtime.client_query import DeleteEntityQuery, ServiceOperationQuery
+from office365.runtime.client_query import DeleteEntityQuery
 from office365.runtime.client_result import ClientResult
 from office365.runtime.resource_path import ResourcePath
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.http.request_options import RequestOptions
+from office365.runtime.serviceOperationQuery import ServiceOperationQuery
+from office365.sharepoint.fileVersionCollection import FileVersionCollection
 from office365.sharepoint.listitem import ListItem
 from office365.sharepoint.webparts.limited_webpart_manager import LimitedWebPartManager
 
 
+class DownloadFileQuery(ServiceOperationQuery):
+
+    def __init__(self, web, file_url, file_object):
+        self.file_object = file_object
+        web.context.get_pending_request().beforeExecute += self._construct_download_query
+        web.context.get_pending_request().afterExecute += self._process_response
+        super(DownloadFileQuery, self).__init__(web, r"getFileByServerRelativeUrl('{0}')/\$value".format(file_url))
+
+    def _construct_download_query(self, request):
+        self.binding_type.context.get_pending_request().beforeExecute -= self._construct_download_query
+        request.method = HttpMethod.Get
+
+    def _process_response(self, response):
+        self.binding_type.context.get_pending_request().afterExecute -= self._process_response
+        self.file_object.write(response.content)
+
+
 class AbstractFile(ClientObject):
-    def read(self, response_object=False):
+    def read(self):
         """Immediately read content of file"""
         if not self.is_property_available("ServerRelativeUrl"):
             raise ValueError
         response = File.open_binary(
             self.context, self.properties["ServerRelativeUrl"])
-        if not response_object:
-            return response.content
-        return response
+        return response.content
 
     def write(self, content):
         """Immediately writes content of file"""
@@ -39,7 +57,10 @@ class File(AbstractFile):
     or a file in a folder."""
 
     def approve(self, comment):
-        """Approves the file submitted for content approval with the specified comment."""
+        """Approves the file submitted for content approval with the specified comment.
+
+        :type comment: str
+        """
         qry = ServiceOperationQuery(self,
                                     "approve",
                                     {
@@ -48,7 +69,10 @@ class File(AbstractFile):
         self.context.add_query(qry)
 
     def deny(self, comment):
-        """Denies approval for a file that was submitted for content approval."""
+        """Denies approval for a file that was submitted for content approval.
+
+        :type comment: str
+        """
         qry = ServiceOperationQuery(self,
                                     "deny",
                                     {
@@ -57,7 +81,11 @@ class File(AbstractFile):
         self.context.add_query(qry)
 
     def copyto(self, new_relative_url, overwrite):
-        """Copies the file to the destination URL."""
+        """Copies the file to the destination URL.
+
+        :type new_relative_url: str
+        :type overwrite: bool
+        """
         qry = ServiceOperationQuery(self,
                                     "copyto",
                                     {
@@ -68,7 +96,11 @@ class File(AbstractFile):
         self.context.add_query(qry)
 
     def moveto(self, new_relative_url, flag):
-        """Moves the file to the specified destination URL."""
+        """Moves the file to the specified destination URL.
+
+        :type new_relative_url: str
+        :type flag: int
+        """
         qry = ServiceOperationQuery(self,
                                     "moveto",
                                     {
@@ -79,7 +111,9 @@ class File(AbstractFile):
         self.context.add_query(qry)
 
     def publish(self, comment):
-        """Submits the file for content approval with the specified comment."""
+        """Submits the file for content approval with the specified comment.
+        :type comment: str
+        """
         qry = ServiceOperationQuery(self,
                                     "publish",
                                     {
@@ -89,7 +123,9 @@ class File(AbstractFile):
         self.context.add_query(qry)
 
     def unpublish(self, comment):
-        """Removes the file from content approval or unpublish a major version."""
+        """Removes the file from content approval or unpublish a major version.
+        :type comment: str
+        """
         qry = ServiceOperationQuery(self,
                                     "unpublish",
                                     {
@@ -137,8 +173,8 @@ class File(AbstractFile):
                                      ResourcePathServiceOperation(
                                          "getlimitedwebpartmanager",
                                          [scope],
-                                         self.resourcePath
-                                         ))
+                                         self.resource_path
+                                     ))
 
     def start_upload(self, upload_id, content):
         """Starts a new chunk upload session and uploads the first fragment."""
@@ -189,9 +225,13 @@ class File(AbstractFile):
 
     @staticmethod
     def save_binary(ctx, server_relative_url, content):
-        """Uploads a file"""
+        """Uploads a file
+        :type ctx: ClientContext
+        :type server_relative_url: str
+        :type content: str
+        """
         url = r"{0}web/getfilebyserverrelativeurl('{1}')/\$value".format(
-            ctx.serviceRootUrl, server_relative_url)
+            ctx.service_root_url, server_relative_url)
         request = RequestOptions(url)
         request.method = HttpMethod.Post
         request.set_header('X-HTTP-Method', 'PUT')
@@ -201,19 +241,49 @@ class File(AbstractFile):
 
     @staticmethod
     def open_binary(ctx, server_relative_url):
-        url = r"{0}web/getfilebyserverrelativeurl('{1}')/\$value".format(ctx.serviceRootUrl, server_relative_url)
+        """
+        Returns the file object located at the specified server-relative URL.
+        :type ctx: ClientContext
+        :type server_relative_url: str
+        """
+        url = r"{0}web/getfilebyserverrelativeurl('{1}')/\$value".format(ctx.service_root_url, server_relative_url)
         request = RequestOptions(url)
         request.method = HttpMethod.Get
         response = ctx.execute_request_direct(request)
         return response
 
+    def download(self, file_object):
+        """Download a file content"""
+        self.ensure_property("ServerRelativeUrl", partial(self._download_inner, file_object))
+
+    def _download_inner(self, file_object, target_file):
+        file_url = target_file.properties['ServerRelativeUrl']
+        qry = DownloadFileQuery(self.context.web, file_url, file_object)
+        self.context.add_query(qry)
+
     @property
     def listItemAllFields(self):
         """Gets a value that specifies the list item field values for the list item corresponding to the file."""
         if self.is_property_available('ListItemAllFields'):
             return self.properties['ListItemAllFields']
         else:
-            return ListItem(self.context, ResourcePath("listItemAllFields", self.resourcePath))
+            return ListItem(self.context, ResourcePath("listItemAllFields", self.resource_path))
+
+    @property
+    def versions(self):
+        """Gets a value that returns a collection of file version objects that represent the versions of the file."""
+        if self.is_property_available('Versions'):
+            return self.properties['Versions']
+        else:
+            return FileVersionCollection(self.context, ResourcePath("versions", self.resource_path))
+
+    @property
+    def serverRelativeUrl(self):
+        """Gets the relative URL of the file based on the URL for the server."""
+        if self.is_property_available('ServerRelativeUrl'):
+            return self.properties["ServerRelativeUrl"]
+        else:
+            return None
 
     def set_property(self, name, value, persist_changes=True):
         super(File, self).set_property(name, value, persist_changes)
@@ -229,4 +299,3 @@ class File(AbstractFile):
                     "GetFileById",
                     [value],
                     ResourcePath("Web"))
-
