@@ -1,6 +1,8 @@
-from office365.runtime.client_query import UpdateEntityQuery, DeleteEntityQuery, ServiceOperationQuery
+from office365.runtime.client_query import UpdateEntityQuery, DeleteEntityQuery
 from office365.runtime.resource_path import ResourcePath
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
+from office365.runtime.serviceOperationQuery import ServiceOperationQuery
+from office365.sharepoint.camlQuery import CamlQuery
 from office365.sharepoint.content_type_collection import ContentTypeCollection
 from office365.sharepoint.field_collection import FieldCollection
 from office365.sharepoint.folder import Folder
@@ -16,35 +18,41 @@ class List(SecurableObject):
 
     def __init__(self, context, resource_path=None):
         super(List, self).__init__(context, resource_path)
-        self._items = None
 
     def get_items(self, caml_query=None):
-        """Returns a collection of items from the list based on the specified query."""
-        self._items = ListItemCollection(self.context, ResourcePath("items", self.resourcePath))
-        if caml_query:
-            qry = ServiceOperationQuery(self, "GetItems", None, caml_query, "query", self._items)
-            self.context.add_query(qry)
-        return self._items
+        """Returns a collection of items from the list based on the specified query.
+        :type caml_query: CamlQuery
+        """
+        if not caml_query:
+            caml_query = CamlQuery.create_all_items_query()
+        items = ListItemCollection(self.context, ResourcePath("items", self.resource_path))
+        qry = ServiceOperationQuery(self, "GetItems", None, caml_query, "query", items)
+        self.context.add_query(qry)
+        return items
 
     def add_item(self, list_item_creation_information):
         """The recommended way to add a list item is to send a POST request to the ListItemCollection resource endpoint,
-         as shown in ListItemCollection request examples."""
+         as shown in ListItemCollection request examples.
+         :type list_item_creation_information: ListItemCreationInformation"""
         item = ListItem(self.context, None, list_item_creation_information)
-        if self._items is None:
-            self._items = ListItemCollection(self.context, ResourcePath("items", self.resourcePath))
-        self._items.add_child(item)
+        self.items.add_child(item)
+        item.ensure_type_name(self)
         qry = ServiceOperationQuery(self, "items", None, item, None, item)
         self.context.add_query(qry)
         return item
 
     def get_item_by_id(self, item_id):
-        """Returns the list item with the specified list item identifier."""
+        """Returns the list item with the specified list item identifier.
+        :type item_id: int
+        """
         return ListItem(self.context,
-                        ResourcePathServiceOperation("getitembyid", [item_id], self.resourcePath))
+                        ResourcePathServiceOperation("getItemById", [item_id], self.resource_path))
 
     def get_view(self, view_id):
-        """Returns the list view with the specified view identifier."""
-        view = View(self.context, ResourcePathServiceOperation("getview", [view_id], self.resourcePath))
+        """Returns the list view with the specified view identifier.
+        :type view_id: str
+        """
+        view = View(self.context, ResourcePathServiceOperation("getView", [view_id], self.resource_path), self)
         return view
 
     def update(self):
@@ -57,13 +65,21 @@ class List(SecurableObject):
         self.context.add_query(qry)
         self.remove_from_parent_collection()
 
+    @property
+    def items(self):
+        """Get list items"""
+        if self.is_property_available('Items'):
+            return self.properties["Items"]
+        else:
+            return ListItemCollection(self.context, ResourcePath("items", self.resource_path))
+
     @property
     def rootFolder(self):
         """Get a root folder"""
         if self.is_property_available('RootFolder'):
             return self.properties["RootFolder"]
         else:
-            return Folder(self.context, ResourcePath("RootFolder", self.resourcePath))
+            return Folder(self.context, ResourcePath("RootFolder", self.resource_path))
 
     @property
     def fields(self):
@@ -71,7 +87,7 @@ class List(SecurableObject):
         if self.is_property_available('Fields'):
             return self.properties['Fields']
         else:
-            return FieldCollection(self.context, ResourcePath("Fields", self.resourcePath))
+            return FieldCollection(self.context, ResourcePath("Fields", self.resource_path))
 
     @property
     def views(self):
@@ -80,7 +96,15 @@ class List(SecurableObject):
         if self.is_property_available('Views'):
             return self.properties['Views']
         else:
-            return ViewCollection(self.context, ResourcePath("views", self.resourcePath))
+            return ViewCollection(self.context, ResourcePath("views", self.resource_path), self)
+
+    @property
+    def defaultView(self):
+        """Gets or sets a value that specifies whether the list view is the default list view."""
+        if self.is_property_available('DefaultView'):
+            return self.properties['DefaultView']
+        else:
+            return View(self.context, ResourcePath("DefaultView", self.resource_path), self)
 
     @property
     def contentTypes(self):
@@ -89,7 +113,7 @@ class List(SecurableObject):
             return self.properties['ContentTypes']
         else:
             return ContentTypeCollection(self.context,
-                                         ResourcePath("contenttypes", self.resourcePath))
+                                         ResourcePath("contenttypes", self.resource_path))
 
     def set_property(self, name, value, persist_changes=True):
         super(List, self).set_property(name, value, persist_changes)
@@ -97,7 +121,7 @@ class List(SecurableObject):
         if self._resource_path is None:
             if name == "Id":
                 self._resource_path = ResourcePathServiceOperation(
-                    "GetById", [value], self._parent_collection.resourcePath)
+                    "GetById", [value], self._parent_collection.resource_path)
             elif name == "Title":
                 self._resource_path = ResourcePathServiceOperation(
-                    "GetByTitle", [value], self._parent_collection.resourcePath)
+                    "GetByTitle", [value], self._parent_collection.resource_path)
