@@ -6,6 +6,3 @@ class ViewFieldCollection(ClientObjectCollection):
     """Represents a collection of Field resources."""
     def __init__(self, context, resource_path=None):
         super(ViewFieldCollection, self).__init__(context, Field, resource_path)
-
-    def map_json(self, json):
-        super(ViewFieldCollection, self).map_json(json)
